@@ -1,17 +1,24 @@
 """Constants."""
+import os
+
 import jmespath
 
 PROJECT_NAME = "nitpick"
-ERROR_PREFIX = "NIP"
+FLAKE8_PREFIX = "NIP"
 CACHE_DIR_NAME = ".cache"
 TOML_EXTENSION = ".toml"
-NITPICK_STYLE_TOML = "nitpick-style{}".format(TOML_EXTENSION)
-MERGED_STYLE_TOML = "merged-style{}".format(TOML_EXTENSION)
-RAW_GITHUB_CONTENT_BASE_URL = "https://raw.githubusercontent.com/andreoliwa/{}".format(PROJECT_NAME)
+NITPICK_STYLE_TOML = f"nitpick-style{TOML_EXTENSION}"
+MERGED_STYLE_TOML = f"merged-style{TOML_EXTENSION}"
+RAW_GITHUB_CONTENT_BASE_URL = f"https://raw.githubusercontent.com/andreoliwa/{PROJECT_NAME}"
 READ_THE_DOCS_URL = "https://nitpick.rtfd.io/en/latest/"
-MANAGE_PY = "manage.py"
+
+# Special files
+PYPROJECT_TOML = "pyproject.toml"
+SETUP_CFG = "setup.cfg"
 ROOT_PYTHON_FILES = ("setup.py", "app.py", "wsgi.py", "autoapp.py")
-ROOT_FILES = ("requirements*.txt", "Pipfile") + ROOT_PYTHON_FILES
+ROOT_FILES = (PYPROJECT_TOML, SETUP_CFG, "requirements*.txt", "Pipfile") + ROOT_PYTHON_FILES
+MANAGE_PY = "manage.py"
+PRE_COMMIT_CONFIG_YAML = ".pre-commit-config.yaml"
 
 SINGLE_QUOTE = "'"
 DOUBLE_QUOTE = '"'
@@ -30,3 +37,7 @@ TOOL_NITPICK = "tool.nitpick"
 TOOL_NITPICK_JMEX = jmespath.compile(TOOL_NITPICK)
 NITPICK_STYLES_INCLUDE_JMEX = jmespath.compile("nitpick.styles.include")
 NITPICK_MINIMUM_VERSION_JMEX = jmespath.compile("nitpick.minimum_version")
+
+#: Dot/slash is used to indicate a local style file
+SLASH = os.path.sep
+DOT_SLASH = f".{SLASH}"
