@@ -2,13 +2,13 @@
 import abc
 import io
 import json
-import logging
 from collections import OrderedDict
 from pathlib import Path
 from typing import Any, Callable, List, Optional, Type, Union
 
 import dictdiffer
 import toml
+from loguru import logger
 from ruamel.yaml import YAML, RoundTripRepresenter
 from ruamel.yaml.comments import CommentedMap, CommentedSeq
 from sortedcontainers import SortedDict
@@ -16,8 +16,6 @@ from sortedcontainers import SortedDict
 from nitpick.generic import flatten, unflatten
 from nitpick.typedefs import JsonDict, PathOrStr, YamlData
 
-LOGGER = logging.getLogger(__name__)
-
 
 class Comparison:
     """A comparison between two dictionaries, computing missing items and differences."""
@@ -33,12 +31,17 @@ class Comparison:
 
         self.format_class = format_class
 
-        self.missing_format = None  # type: Optional[BaseFormat]
+        self.missing = None  # type: Optional[BaseFormat]
         self.missing_dict = {}  # type: Union[JsonDict, YamlData]
 
-        self.diff_format = None  # type: Optional[BaseFormat]
+        self.diff = None  # type: Optional[BaseFormat]
         self.diff_dict = {}  # type: Union[JsonDict, YamlData]
 
+    @property
+    def has_changes(self) -> bool:
+        """Return True is there is a difference or something missing."""
+        return bool(self.missing or self.diff)
+
     @staticmethod
     def _normalize_value(value: Union[JsonDict, YamlData, "BaseFormat"]) -> JsonDict:
         if isinstance(value, BaseFormat):
@@ -53,7 +56,7 @@ class Comparison:
             return
         self.missing_dict = missing_dict
         if self.format_class:
-            self.missing_format = self.format_class(data=missing_dict)
+            self.missing = self.format_class(data=missing_dict)
 
     def set_diff(self, diff_dict):
         """Set the diff dict and corresponding format."""
@@ -61,7 +64,7 @@ class Comparison:
             return
         self.diff_dict = diff_dict
         if self.format_class:
-            self.diff_format = self.format_class(data=diff_dict)
+            self.diff = self.format_class(data=diff_dict)
 
     def update_pair(self, key, raw_expected):
         """Update a key on one of the comparison dicts, with its raw expected value."""
@@ -80,7 +83,7 @@ class Comparison:
                 self.diff_dict.update(unflatten({key[0]: raw_expected}))
                 return
 
-        LOGGER.warning("Err... this is unexpected, please open an issue: key=%s raw_expected=%s", key, raw_expected)
+        logger.warning("Err... this is unexpected, please open an issue: key={} raw_expected={}", key, raw_expected)
 
 
 class BaseFormat(metaclass=abc.ABCMeta):
@@ -205,15 +208,6 @@ class BaseFormat(metaclass=abc.ABCMeta):
 class TOMLFormat(BaseFormat):
     """TOML configuration format."""
 
-    @staticmethod
-    def group_name_for(file_name: str) -> str:
-        """Return a TOML group name for a file name.
-
-        If the file name begins with a dot, remove it.
-        Otherwise an error is raised: TomlDecodeError: Invalid group name 'xxx'. Try quoting it.
-        """
-        return file_name.lstrip(".")
-
     def load(self) -> bool:
         """Load a TOML file by its path, a string or a dict."""
         if self._loaded:
