@@ -1,6 +1,5 @@
 """Text files."""
-import logging
-from typing import Optional, Set, Type
+from typing import Iterator, Optional, Type
 
 from marshmallow import Schema
 from marshmallow.orderedset import OrderedSet
@@ -8,12 +7,11 @@ from marshmallow.orderedset import OrderedSet
 from nitpick import fields
 from nitpick.plugins import hookimpl
 from nitpick.plugins.base import NitpickPlugin
+from nitpick.plugins.info import FileInfo
 from nitpick.schemas import help_message
-from nitpick.typedefs import JsonDict, YieldFlake8Error
+from nitpick.violations import Fuss, ViolationEnum
 
-LOGGER = logging.getLogger(__name__)
-
-TEXT_FILE_RTFD_PAGE = "config_files.html#text-files"
+TEXT_FILE_RTFD_PAGE = "plugins.html#text-files"
 
 
 class TextItemSchema(Schema):
@@ -30,8 +28,14 @@ class TextSchema(Schema):
     contains = fields.List(fields.Nested(TextItemSchema))
 
 
+class Violations(ViolationEnum):
+    """Violations for this plugin."""
+
+    MISSING_LINES = (352, " has missing lines:")
+
+
 class TextPlugin(NitpickPlugin):
-    """Checker for text files.
+    """Enforce configuration on text files.
 
     To check if ``some.txt`` file contains the lines ``abc`` and ``def`` (in any order):
 
@@ -44,24 +48,30 @@ class TextPlugin(NitpickPlugin):
         line = "def"
     """
 
-    error_base_number = 350
-    identify_tags = {"plain-text"}
+    identify_tags = {"text"}
     validation_schema = TextSchema
 
-    def _expected_lines(self):
-        return [obj.get("line") for obj in self.file_dict.get("contains", {})]
+    #: All other files are also text files, and they already have a suggested content message
+    # TODO: this is a hack to avoid rethinking the whole schema validation now (this will have to be done some day)
+    skip_empty_suggestion = True
 
-    def suggest_initial_contents(self) -> str:
+    violation_base_code = 350
+
+    def _expected_lines(self):
+        return [obj.get("line") for obj in self.expected_config.get("contains", {})]
+
+    @property
+    def initial_contents(self) -> str:
         """Suggest the initial content for this missing file."""
         return "\n".join(self._expected_lines())
 
-    def check_rules(self) -> YieldFlake8Error:
-        """Check missing lines."""
+    def enforce_rules(self) -> Iterator[Fuss]:
+        """Enforce rules for missing lines."""
         expected = OrderedSet(self._expected_lines())
         actual = OrderedSet(self.file_path.read_text().split("\n"))
         missing = expected - actual
         if missing:
-            yield self.flake8_error(2, " has missing lines:", "\n".join(sorted(missing)))
+            yield self.reporter.make_fuss(Violations.MISSING_LINES, "\n".join(sorted(missing)))
 
 
 @hookimpl
@@ -71,6 +81,8 @@ def plugin_class() -> Type["NitpickPlugin"]:
 
 
 @hookimpl
-def handle_config_file(config: JsonDict, file_name: str, tags: Set[str]) -> Optional["NitpickPlugin"]:
+def can_handle(info: FileInfo) -> Optional[Type["NitpickPlugin"]]:
     """Handle text files."""
-    return TextPlugin(config, file_name) if "plain-text" in tags else None
+    if TextPlugin.identify_tags & info.tags:
+        return TextPlugin
+    return None
