@@ -8,7 +8,6 @@ from sortedcontainers import SortedDict
 from nitpick import fields
 from nitpick.constants import READ_THE_DOCS_URL
 from nitpick.generic import flatten
-from nitpick.plugins.setup_cfg import SetupCfgPlugin
 
 
 def flatten_marshmallow_errors(errors: Dict) -> str:
@@ -16,11 +15,9 @@ def flatten_marshmallow_errors(errors: Dict) -> str:
     formatted = []
     for field, data in SortedDict(flatten(errors)).items():
         if isinstance(data, list):
-            messages_per_field = ["{}: {}".format(field, ", ".join(data))]
+            messages_per_field = [f"{field}: {', '.join(data)}"]
         elif isinstance(data, dict):
-            messages_per_field = [
-                "{}[{}]: {}".format(field, index, ", ".join(messages)) for index, messages in data.items()
-            ]
+            messages_per_field = [f"{field}[{index}]: {', '.join(messages)}" for index, messages in data.items()]
         else:
             # This should never happen; if it does, let's just convert to a string
             messages_per_field = [str(errors)]
@@ -31,7 +28,7 @@ def flatten_marshmallow_errors(errors: Dict) -> str:
 def help_message(sentence: str, help_page: str) -> str:
     """Show help with the documentation URL on validation errors."""
     clean_sentence = sentence.strip(" .")
-    return "{}. See {}{}.".format(clean_sentence, READ_THE_DOCS_URL, help_page)
+    return f"{clean_sentence}. See {READ_THE_DOCS_URL}{help_page}."
 
 
 class BaseNitpickSchema(Schema):
@@ -40,14 +37,6 @@ class BaseNitpickSchema(Schema):
     error_messages = {"unknown": help_message("Unknown configuration", "nitpick_section.html")}
 
 
-class ToolNitpickSectionSchema(BaseNitpickSchema):
-    """Validation schema for the ``[tool.nitpick]`` section on ``pyproject.toml``."""
-
-    error_messages = {"unknown": help_message("Unknown configuration", "tool_nitpick_section.html")}
-
-    style = PolyField(deserialization_schema_selector=fields.string_or_list_field)
-
-
 class NitpickStylesSectionSchema(BaseNitpickSchema):
     """Validation schema for the ``[nitpick.styles]`` section on the style file."""
 
@@ -72,7 +61,7 @@ class NitpickFilesSectionSchema(BaseNitpickSchema):
     absent = fields.Dict(fields.NonEmptyString, fields.String())
     present = fields.Dict(fields.NonEmptyString, fields.String())
     # TODO: load this schema dynamically, then add this next field setup_cfg
-    setup_cfg = fields.Nested(SetupCfgSchema, data_key=SetupCfgPlugin.file_name)
+    setup_cfg = fields.Nested(SetupCfgSchema, data_key="setup.cfg")
 
 
 class NitpickSectionSchema(BaseNitpickSchema):
@@ -86,6 +75,6 @@ class NitpickSectionSchema(BaseNitpickSchema):
 class BaseStyleSchema(Schema):
     """Base validation schema for style files. Dynamic fields will be added to it later."""
 
-    error_messages = {"unknown": help_message("Unknown file", "config_files.html")}
+    error_messages = {"unknown": help_message("Unknown file", "plugins.html")}
 
     nitpick = fields.Nested(NitpickSectionSchema)
